@@ -7,13 +7,23 @@ from shareplum.site import Version
 class SPInterface:
     """This is a class to interact with Sharepoint from Python"""
 
+    global authcookie
+
     def __init__(self, sharepoint_base_url, username, password):
         self.username = username
         self.password = password
         self.sharepoint_base_url = sharepoint_base_url
         self.authcookie = Office365(sharepoint_base_url, username=username, password=password).GetCookies()
 
+
     def download_file_sharepoint(self,source_path, sink_path, filename, sharepoint_site):
+        """This fucntion will download a file from the Sharepoint to specified sink path.
+        Parameters:
+            source_path = r'Shared Documents/Shared/<Location>'
+            sink_path = r'/full_sink_path/'
+            filename = 'filename.ext'
+            sharepoint_site = 'https://tsx.sharepoint.com/sites/<site_name>'
+        """
         site = Site(sharepoint_site, version=Version.v2016, authcookie=authcookie)
         full_source_path = os.path.join(source_path, filename)
         full_sink_path = os.path.join(sink_path, filename)
@@ -39,25 +49,32 @@ class SPInterface:
 
 
     def upload_file_sharepoint(self, source_path,sink_path,filename,sharepoint_site):
-      site = Site(sharepoint_site, version=Version.v2016, authcookie=authcookie)
-      full_source_path=os.path.join(source_path,filename)
-      full_sink_path=os.path.join(sink_path,filename)
-      print(full_source_path)
-      print(full_sink_path)
-      folder = site.Folder(sink_path)
-      with open(full_source_path, mode='rb') as file:
-        filecontent = file.read()
-      for attempt in range(0,3):
-        try:
-          folder.upload_file(filecontent, full_sink_path)
-          print("Attempt No:", attempt)
-        except Exception as e:
-          if(attempt<2):
-            print("Try again!")
-            continue
-          print("Error", e)
-          raise e
-        break
+        """This fucntion will upload a file from the source path to Sharepoint.
+        Parameters:
+            source_path = r'/full_sink_path/'
+            sink_path = r'Shared Documents/Shared/<Location>'
+            filename = 'filename.ext'
+            sharepoint_site = 'https://tsx.sharepoint.com/sites/<site_name>'
+        """
+        site = Site(sharepoint_site, version=Version.v2016, authcookie=authcookie)
+        full_source_path=os.path.join(source_path,filename)
+        full_sink_path=os.path.join(sink_path,filename)
+        print(full_source_path)
+        print(full_sink_path)
+        folder = site.Folder(sink_path)
+        with open(full_source_path, mode='rb') as file:
+            filecontent = file.read()
+        for attempt in range(0,3):
+            try:
+              folder.upload_file(filecontent, full_sink_path)
+              print("Attempt No:", attempt)
+            except Exception as e:
+              if(attempt<2):
+                print("Try again!")
+                continue
+              print("Error", e)
+              raise e
+            break
 
 
 def main():
